from setuptools import setup

setup(
    name='gbinomial_probability',
    version='1.0',
    description='Gaussian and Binomial Distributions',
    packages=['gbinomial_probability'],
    author= 'Seah Mei Yin',
    author_email= 'tiffanyseah94@gmail.com',
    zip_safe=False)